# metadata

This repository contains state metadata that powers Open States.

[![CircleCI](https://circleci.com/gh/openstates/metadata.svg?style=svg)](https://circleci.com/gh/openstates/metadata)

## Links

* [Open States Discourse](https://discourse.openstates.org)
* [Code of Conduct](https://docs.openstates.org/en/latest/contributing/code-of-conduct.html)
